==> happytimer_0.9.10.tar.gz: happytimer_0.9.10/happytimer.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/********************************************
 * main 파일입니다.
 * 사용자 설정파일을 체크하는 부분이
 * 포함되어 있습니다.
 * ******************************************/

#include <gtk/gtk.h>
#include <regex.h>
#include <string.h>
#include <unistd.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libsexy/sexy-tooltip.h>
#include "happytimer.h"
#include "interface.h"
#include "callback.h"
#include "timecheck.h"

static void preference_check(void);

int main(int argc, char *argv[])
{
	int count;
	GtkWidget *trayiconEbox;

	gtk_init(&argc, &argv);
	gst_init(0, NULL);

	varList.countdown = FALSE;
	regcomp(&varList.mregex, "..0000", 0);
	varList.repeat = FALSE;
	varList.spin_hr = varList.spin_min = varList.spin_sec = 0;

	preference_check();

	trayicon = egg_tray_icon_new("happytimer");
	gtk_widget_show(GTK_WIDGET(trayicon));

	trayiconEbox = gtk_event_box_new();
	gtk_container_add(GTK_CONTAINER(trayicon), trayiconEbox);
	gtk_widget_show(trayiconEbox);
	g_signal_connect(G_OBJECT(trayiconEbox), "enter_notify_event",
				G_CALLBACK(on_trayiconEbox_enter_notify_event), NULL);
	g_signal_connect(G_OBJECT(trayiconEbox), "leave_notify_event",
				G_CALLBACK(on_trayiconEbox_leave_notify_event), NULL);
	g_signal_connect(G_OBJECT(trayiconEbox), "button_press_event",
				G_CALLBACK(on_trayiconEbox_button_press_event), NULL);

	trayiconImage = gtk_image_new_from_file(TRAY_IMAGE);
	gtk_container_add(GTK_CONTAINER(trayiconEbox), trayiconImage);
	gtk_widget_show(GTK_WIDGET(trayiconImage));

	trayiconTooltip = sexy_tooltip_new();
	sexy_tooltip_position_to_widget(SEXY_TOOLTIP(trayiconTooltip), trayiconEbox);

	tooltipTimer_label = gtk_label_new("Happytimer\n00hr 00min 00sec");
	gtk_container_add(GTK_CONTAINER(trayiconTooltip), tooltipTimer_label);
	gtk_widget_show(tooltipTimer_label);

	menu = create_menu();
	timer = create_timer();
	alarm_window = NULL;

	/* gstreamer를 사용하여 사운드를 초기화 */
	for (count = 0; count < SND_NUM; count++)
		gstSound[count] = gst_element_factory_make("playbin", "playbin");

	g_timeout_add(1000, (GtkFunction)timeCheck, NULL);

	gtk_main();

	return 0;
}

/* 설정 파일을 읽어 옵니다. */
static void read_preference_xml(xmlNodePtr node)
{
	xmlNodePtr cur_node = NULL;

	for (cur_node = node; cur_node; cur_node = cur_node->next) {
		if (cur_node->type == XML_ELEMENT_NODE) {
			if (!strcmp((char *) cur_node->name, "rtsound")) {
				free(prefer.rtsound);
				prefer.rtsound = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "tsound")) {
				free(prefer.tsound);
				prefer.tsound = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "tsoundfile")) {
				free(prefer.tsoundfile);
				prefer.tsoundfile = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "timagefile")) {
				free(prefer.timagefile);
				prefer.timagefile = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "rtsound_dir")) {
				free(prefer.rtsound_dir);
				prefer.rtsound_dir = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "maxtimer")) {
				free(prefer.maxtimer);
				prefer.maxtimer = strdup((char *) cur_node->children->content);
			}
		}

		read_preference_xml(cur_node->children);
	}
}

/* 설정파일 검사 */
static void preference_check(void)
{
	char buf1[256], buf2[256];
	xmlDocPtr doc;
	xmlNodePtr root_node, node1, node2;
	FILE *fp;
	int count = 0;
	char *preset_list[][2] = {{"계란삶기", "720"},
						{"녹차", "180"},
						{"다즐링", "220"},
						{NULL, NULL}

	};

	prefer.rtsound = strdup("on");
	prefer.tsound = strdup("on");
	prefer.tsoundfile = strdup("/usr/share/happytimer/sound/Bells pad melody swell_BLASTWAVEFX_19061.mp3");
	prefer.timagefile = strdup("/usr/share/pixmaps/happytimer.png");
	prefer.rtsound_dir = strdup(HAPPYTIMER_SOUND);
	prefer.maxtimer = strdup(MAX_TIMER);

	sprintf(buf1, "%s%s", g_get_home_dir(), "/.happytimer_xml");
	prefer.prefer_file = strdup(buf1);

	if (access(prefer.prefer_file, F_OK)) {
		doc = xmlNewDoc(BAD_CAST "1.0");
		root_node = xmlNewNode(NULL, BAD_CAST "HAPPYTIMER");
		xmlNewProp(root_node, BAD_CAST "document_version", BAD_CAST "0.9.9");
		xmlDocSetRootElement(doc, root_node);
			node1 = xmlNewChild(root_node, NULL, BAD_CAST "config", NULL);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "rtsound", BAD_CAST prefer.rtsound);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "tsound", BAD_CAST prefer.tsound);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "tsoundfile", BAD_CAST prefer.tsoundfile);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "timagefile", BAD_CAST prefer.timagefile);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "rtsound_dir", BAD_CAST prefer.rtsound_dir);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "maxtimer", BAD_CAST prefer.maxtimer);
			node1 = xmlNewChild(root_node, NULL, BAD_CAST "preset_group", NULL);
				while (preset_list[count][0] != NULL) {
					node2 = xmlNewChild(node1, NULL, BAD_CAST "preset", NULL);

						xmlNewProp(node2, BAD_CAST "name", BAD_CAST preset_list[count][0]);
						xmlNewProp(node2, BAD_CAST "timer", BAD_CAST preset_list[count][1]);

						count++;
				}				

		xmlSaveFormatFileEnc(prefer.prefer_file, doc, "UTF-8", 1);
		xmlFreeDoc(doc);
	} else {
		if ((doc = xmlReadFile(prefer.prefer_file, NULL, 0)) == NULL) {
			fprintf(stderr, "Document not parsed successfully\n");
			exit(1);
		} else {
			root_node = xmlDocGetRootElement(doc);
			read_preference_xml(root_node);

			xmlFreeDoc(doc);
		}
	}
	
	/* 시간제를 읽어옵니다. */
	sprintf(buf1, "%s/%s", prefer.rtsound_dir, VOICE_INFO);

	if ((fp = fopen(buf1, "r")) == NULL) {
		fprintf(stderr, "Error opening file %s.\nInstead, opening ", buf1);
		sprintf(buf1, "%s%s", HAPPYTIMER_SOUND, VOICE_INFO);
		fprintf(stderr, "%s.\n", buf1);
		fp = fopen(buf1, "r");
	}

	fgets(buf2, 255, fp);
	fgets(buf2, 255, fp);

	buf2[strlen(buf2) - 1] = '\0';
	varList.hour_clock = strdup(buf2);
	
	soundDir_num = 0;

	fgets(buf2, 255, fp);
	buf2[strlen(buf2) - 1] = '\0';
	varList.sf = strdup(buf2);

	fclose(fp);
}

==> happytimer_0.9.11.tar.gz: happytimer_0.9.11/happytimer.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/********************************************
 * main 파일입니다.
 * 사용자 설정파일을 체크하는 부분이
 * 포함되어 있습니다.
 * ******************************************/

#include <gtk/gtk.h>
#include <regex.h>
#include <string.h>
#include <unistd.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libsexy/sexy-tooltip.h>
#include <libintl.h>
#include <locale.h>
#include "happytimer.h"
#include "interface.h"
#include "callback.h"
#include "timecheck.h"

static void preference_check(void);

int main(int argc, char *argv[])
{
	int count;
	GtkWidget *trayiconEbox;

	gtk_init(&argc, &argv);
	gst_init(0, NULL);

	bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
        textdomain(GETTEXT_PACKAGE);

	varList.countdown = FALSE;
	regcomp(&varList.mregex, "..0000", 0);
	varList.repeat = FALSE;
	varList.spin_hr = varList.spin_min = varList.spin_sec = 0;

	preference_check();

	trayicon = egg_tray_icon_new("happytimer");
	gtk_widget_show(GTK_WIDGET(trayicon));

	trayiconEbox = gtk_event_box_new();
	gtk_container_add(GTK_CONTAINER(trayicon), trayiconEbox);
	gtk_widget_show(trayiconEbox);
	g_signal_connect(G_OBJECT(trayiconEbox), "enter_notify_event",
				G_CALLBACK(on_trayiconEbox_enter_notify_event), NULL);
	g_signal_connect(G_OBJECT(trayiconEbox), "leave_notify_event",
				G_CALLBACK(on_trayiconEbox_leave_notify_event), NULL);
	g_signal_connect(G_OBJECT(trayiconEbox), "button_press_event",
				G_CALLBACK(on_trayiconEbox_button_press_event), NULL);

	trayiconImage = gtk_image_new_from_file(TRAY_IMAGE);
	gtk_container_add(GTK_CONTAINER(trayiconEbox), trayiconImage);
	gtk_widget_show(GTK_WIDGET(trayiconImage));

	trayiconTooltip = sexy_tooltip_new();
	sexy_tooltip_position_to_widget(SEXY_TOOLTIP(trayiconTooltip), trayiconEbox);

	tooltipTimer_label = gtk_label_new(_("Happytimer\n00hr 00min 00sec"));
	gtk_container_add(GTK_CONTAINER(trayiconTooltip), tooltipTimer_label);
	gtk_widget_show(tooltipTimer_label);

	menu = create_menu();
	timer = create_timer();
	alarm_window = NULL;

	/* gstreamer를 사용하여 사운드를 초기화 */
	for (count = 0; count < SND_NUM; count++)
		gstSound[count] = gst_element_factory_make("playbin", "playbin");

	g_timeout_add(1000, (GtkFunction)timeCheck, NULL);

	gtk_main();

	return 0;
}

/* 설정 파일을 읽어 옵니다. */
static void read_preference_xml(xmlNodePtr node)
{
	xmlNodePtr cur_node = NULL;

	for (cur_node = node; cur_node; cur_node = cur_node->next) {
		if (cur_node->type == XML_ELEMENT_NODE) {
			if (!strcmp((char *) cur_node->name, "rtsound")) {
				free(prefer.rtsound);
				prefer.rtsound = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "tsound")) {
				free(prefer.tsound);
				prefer.tsound = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "tsoundfile")) {
				free(prefer.tsoundfile);
				prefer.tsoundfile = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "timagefile")) {
				free(prefer.timagefile);
				prefer.timagefile = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "rtsound_dir")) {
				free(prefer.rtsound_dir);
				prefer.rtsound_dir = strdup((char *) cur_node->children->content);
			} else if (!strcmp((char *) cur_node->name, "maxtimer")) {
				free(prefer.maxtimer);
				prefer.maxtimer = strdup((char *) cur_node->children->content);
			}
		}

		read_preference_xml(cur_node->children);
	}
}

/* 설정파일 검사 */
static void preference_check(void)
{
	char buf1[256], buf2[256];
	xmlDocPtr doc;
	xmlNodePtr root_node, node1, node2;
	FILE *fp;
	int count = 0;
	char *preset_list[][2] = {{_("Egg boil"), "720"},
						{_("Green tea"), "180"},
						{_("Darjeeling"), "220"},
						{NULL, NULL}

	};

	prefer.rtsound = strdup("on");
	prefer.tsound = strdup("on");
	prefer.tsoundfile = strdup("/usr/share/happytimer/sound/Bells pad melody swell_BLASTWAVEFX_19061.mp3");
	prefer.timagefile = strdup("/usr/share/pixmaps/happytimer.png");
	prefer.rtsound_dir = strdup(HAPPYTIMER_SOUND);
	prefer.maxtimer = strdup(MAX_TIMER);

	sprintf(buf1, "%s%s", g_get_home_dir(), "/.happytimer_xml");
	prefer.prefer_file = strdup(buf1);

	if (access(prefer.prefer_file, F_OK)) {
		doc = xmlNewDoc(BAD_CAST "1.0");
		root_node = xmlNewNode(NULL, BAD_CAST "HAPPYTIMER");
		xmlNewProp(root_node, BAD_CAST "document_version", BAD_CAST "0.9.9");
		xmlDocSetRootElement(doc, root_node);
			node1 = xmlNewChild(root_node, NULL, BAD_CAST "config", NULL);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "rtsound", BAD_CAST prefer.rtsound);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "tsound", BAD_CAST prefer.tsound);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "tsoundfile", BAD_CAST prefer.tsoundfile);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "timagefile", BAD_CAST prefer.timagefile);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "rtsound_dir", BAD_CAST prefer.rtsound_dir);
				node2 = xmlNewChild(node1, NULL, BAD_CAST "maxtimer", BAD_CAST prefer.maxtimer);
			node1 = xmlNewChild(root_node, NULL, BAD_CAST "preset_group", NULL);
				while (preset_list[count][0] != NULL) {
					node2 = xmlNewChild(node1, NULL, BAD_CAST "preset", NULL);

						xmlNewProp(node2, BAD_CAST "name", BAD_CAST preset_list[count][0]);
						xmlNewProp(node2, BAD_CAST "timer", BAD_CAST preset_list[count][1]);

						count++;
				}				

		xmlSaveFormatFileEnc(prefer.prefer_file, doc, "UTF-8", 1);
		xmlFreeDoc(doc);
	} else {
		if ((doc = xmlReadFile(prefer.prefer_file, NULL, 0)) == NULL) {
			fprintf(stderr, "Document not parsed successfully\n");
			exit(1);
		} else {
			root_node = xmlDocGetRootElement(doc);
			read_preference_xml(root_node);

			xmlFreeDoc(doc);
		}
	}
	
	/* 시간제를 읽어옵니다. */
	sprintf(buf1, "%s/%s", prefer.rtsound_dir, VOICE_INFO);

	if ((fp = fopen(buf1, "r")) == NULL) {
		fprintf(stderr, "Error opening file %s.\nInstead, opening ", buf1);
		sprintf(buf1, "%s%s", HAPPYTIMER_SOUND, VOICE_INFO);
		fprintf(stderr, "%s.\n", buf1);
		fp = fopen(buf1, "r");
	}

	fgets(buf2, 255, fp);
	fgets(buf2, 255, fp);

	buf2[strlen(buf2) - 1] = '\0';
	varList.hour_clock = strdup(buf2);
	
	soundDir_num = 0;

	fgets(buf2, 255, fp);
	buf2[strlen(buf2) - 1] = '\0';
	varList.sf = strdup(buf2);

	fclose(fp);
}
